@@ -65,9 +65,8 @@ sub srv {
     Danga::Socket->AddTimer(5.0, sub {
         return if $self->{became_readable};
         $self->{timed_out} = 1;
-        $logger->debug("DNS 'SRV' lookup for '$hostname' timed out");
+        $logger->debug("DNS lookup for '$hostname' timed out");
         $callback->();
-        $self->close;
     });
 
     $self->watch_read(1);
@@ -109,7 +108,7 @@ sub new {
     Danga::Socket->AddTimer(5.0, sub {
         return if $self->{became_readable};
         $self->{timed_out} = 1;
-        $logger->debug("DNS 'A' lookup for '$hostname' timed out");
+        $logger->debug("DNS lookup for '$hostname' timed out");
         $callback->();
         $self->close;
     });
@@ -197,7 +196,7 @@ sub event_read_srv {
     my @targets = sort {
         $a->priority <=> $b->priority ||
         $a->weight   <=> $b->weight
-    } grep { ref $_ eq "Net::DNS::RR::SRV" && $_->port } @ans;
+    } grep { ref $_ eq "Net::DNS::RR::SRV"} @ans;
 
     unless (@targets) {
         # no result, fallback to an A lookup
